@@ -26,7 +26,7 @@
 #       You may only use this script to uninstall the version
 #       shown below. Simply run this script to remove Shorewall Firewall
 
-VERSION=4.4.17
+VERSION=4.4.19.1
 
 usage() # $1 = exit status
 {
@@ -60,6 +60,8 @@ else
     VERSION=""
 fi
 
+[ -n "${LIBEXEC:=share}" ]
+
 echo "Uninstalling Shorewall Init $VERSION"
 
 INITSCRIPT=/etc/init.d/shorewall-init
@@ -105,6 +107,7 @@ if [ -d /etc/ppp ]; then
 fi
 
 rm -rf /usr/share/shorewall-init
+rm -rf /usr/${LIBEXEC}/shorewall-init
 
 echo "Shorewall Init Uninstalled"
 
